<div {% if multifield.css_id or errors %}id="{{ multifield.css_id }}"{% endif %}
    {% if multifield.css_class %}class="{{ multifield.css_class }}"{% endif %}
    {{ multifield.flat_attrs }}>

    {% if form_show_errors %}
        <div class="alert alert-danger" role="alert">
        {% for field in multifield.bound_fields %}
            {% if field.errors %}
                {% for error in field.errors %}
                    <p id="error_{{ forloop.counter }}_{{ field.auto_id }}">{{ error }}</p>
                {% endfor %}
            {% endif %}
        {% endfor %}
        </div>
    {% endif %}

    {% if multifield.label_html %}
        <p {% if multifield.label_class %}class="{{ multifield.label_class }}"{% endif %}>{{ multifield.label_html }}</p>
    {% endif %}

    <div class="multiField">
        {{ fields_output }}
    </div>

</div>
